@@ -1149,7 +1149,8 @@ int busycnt_vzt_c_2; /* from vzt.c 641 */
 /*
  * wavewindow.c
  */
-char use_scrollwheel_as_y; /* fromwavewindow.c */
+char use_scrollwheel_as_y; /* from wavewindow.c */
+char enable_slider_zoom; /* from wavewindow.c */
 int m1x_wavewindow_c_1; /* from wavewindow.c 642 */
 int m2x_wavewindow_c_1; /* from wavewindow.c 643 */
 char black_and_white; /* from wavewindow.c */
@@ -1270,6 +1271,13 @@ GdkGC *gccache_w_wavewindow_c_1; /* from wavewindow.c */
 GdkGC *gccache_dashfill_wavewindow_c_1; /* from wavewindow.c */
 GdkGC *gccache_dash_wavewindow_c_1; /* from wavewindow.c */
 int analog_redraw_skip_count; /* from wavewindow.c */
+int str_wid_x;
+int str_wid_width;
+int str_wid_bigw;
+int str_wid_state;
+int str_wid_slider;
+int str_wid_height;
+
 
 /*
  * zoombuttons.c
