@@ -258,8 +258,7 @@ if(shmid >= 0)
 
 	consume_ptr = buf;
 
-	/* this loop never exits */
-	for(;;)
+	while(!feof(f))
 		{
 		char *s = fgets(l_buf+buf_strlen, 32768-buf_strlen, f);
 		
@@ -319,8 +318,11 @@ return(255);
 
 
 /*
- * $Id: shmidcat.c,v 1.8 2009/12/22 19:57:26 gtkwave Exp $
+ * $Id: shmidcat.c,v 1.9 2011/01/14 16:23:18 gtkwave Exp $
  * $Log: shmidcat.c,v $
+ * Revision 1.9  2011/01/14 16:23:18  gtkwave
+ * modified to exit on EOF
+ *
  * Revision 1.8  2009/12/22 19:57:26  gtkwave
  * warnings fixes on postincrement p++
  *
