@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell and Concept Engineering GmbH 2008-2010.
+ * Copyright (c) Tony Bybell and Concept Engineering GmbH 2008-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1020,7 +1020,7 @@ for(ii=0;ii<c;ii++)
 	unesc_len = strlen(unescaped_str);
 	for(i=0;i<GLOBALS->numfacs;i++)
 	        {
-	        int was_packed;
+	        int was_packed = 0;
 	        char *hfacname = NULL;
 	                                 
        		hfacname = hier_decompress_flagged(GLOBALS->facs[curr_srch_idx]->name, &was_packed);
@@ -1056,7 +1056,7 @@ for(ii=0;ii<c;ii++)
 	wave_regex_compile(entry_suffixed, WAVE_REGEX_DND); 
 	for(i=0;i<GLOBALS->numfacs;i++)
 	        {
-	        int was_packed;
+	        int was_packed = 0;
 	        char *hfacname = NULL;
 	                                 
        		hfacname = hier_decompress_flagged(GLOBALS->facs[i]->name, &was_packed);
@@ -1086,7 +1086,7 @@ for(ii=0;ii<c;ii++)
 		wave_regex_compile(entry_suffixed, WAVE_REGEX_DND); 
 		for(i=0;i<GLOBALS->numfacs;i++)
 		        {
-		        int was_packed;
+		        int was_packed = 0;
 		        char *hfacname = NULL;
 		                                 
         		hfacname = hier_decompress_flagged(GLOBALS->facs[i]->name, &was_packed);
@@ -1313,10 +1313,21 @@ char is_bus = 0;
 
 if(s)
 	{
-	int len = strlen(s);
-	char *s2 = wave_alloca(len+1);
+	int len;
+	int was_packed = 0;
+	char *s2;
+
+	s = hier_decompress_flagged(s, &was_packed);	
+	len = strlen(s);
+	s2 = wave_alloca(len+1);
 	
 	strcpy(s2, s);
+	if(was_packed)
+		{
+		free_2(s);
+		s = NULL; 
+		}
+
 	pnt = s2;
 	while(*pnt)
 		{
@@ -1465,7 +1476,11 @@ if(t)
 						{
 						if(!(h_ptr->flags&HIST_STRING))
 							{
+#ifdef WAVE_HAS_H_DOUBLE
+							rc = convert_ascii_real(t, &h_ptr->v.h_double);
+#else
 							rc = convert_ascii_real(t, (double *)h_ptr->v.h_vector);
+#endif
 							}
 							else
 							{
@@ -1855,8 +1870,8 @@ sig_selection_foreach_dnd
  
   if(!sel) return;
 
-  low = fetchlow(sel)->which;
-  high = fetchhigh(sel)->which;
+  low = fetchlow(sel)->t_which;
+  high = fetchhigh(sel)->t_which;
  
   /* If signals are vectors, iterate through them if so.  */
   for(i=low;i<=high;i++)
@@ -2942,8 +2957,14 @@ return(strdup_2("--script TCL_ERROR : Tcl support not compiled into gtkwave\n"))
 
 
 /*
- * $Id: tcl_helper.c,v 1.93 2010/10/06 21:12:29 gtkwave Exp $
+ * $Id: tcl_helper.c,v 1.95 2011/01/17 19:24:21 gtkwave Exp $
  * $Log: tcl_helper.c,v $
+ * Revision 1.95  2011/01/17 19:24:21  gtkwave
+ * tree modifications to support decorated internal hierarchy nodes
+ *
+ * Revision 1.94  2011/01/13 17:20:39  gtkwave
+ * rewrote hierarchy / facility packing code
+ *
  * Revision 1.93  2010/10/06 21:12:29  gtkwave
  * fix for rpc_script_execute when tcl disabled
  *
